#!/bin/bash
echo "=========================="

if [ $# -eq 1 ];then
 echo "入参：$1"
else
 echo "只允许输入一个参数"
 exit
fi

CLEANSTATUSPATH="/etc/logview/cleanstatus"
CLEANDATEPATH="/etc/logview/cleandate"

init() {
  echo "@reboot root bash /etc/logview/cleanlog.sh check"  > /etc/cron.d/autocleanlog

  if [ ! -f $CLEANSTATUSPATH ];then
    echo "init create $CLEANSTATUSPATH"
    echo "close" > $CLEANSTATUSPATH
  fi

  if [ ! -f $CLEANDATEPATH ];then
    echo "init create $CLEANDATEPATH"
    echo "null" > $CLEANDATEPATH
  fi

}


comunlinklog(){
  for FILE in $(find $1 -name "$2*");do

    echo "====find file $FILE"
    str=$1"/"$2
    str1=$1"/"$2".log"

    if [[ $FILE = $str ]]||[[ $FILE = $str1 ]];then
      echo "null $FILE"
      cat /dev/null > $FILE
    else
      echo "ulink $FILE"
      unlink $FILE
    fi

  done
}
#DIR="/home/ksc-dev/桌面/baklog/log"
#KEY="kern"
#comunlinklog $DIR $KEY


#系统日志
systemlog(){
  echo "系统日志"

  #syslog 使用journalctl命令获取
  rm -r /var/log/journal/*

  #/var/log/Xorg.log
  comunlinklog /var/log "Xorg"

  #/var/log/samba/log.smbd
  comunlinklog /var/log/samba "log.smbd"

  #/var/log/samba/log.nmbd
  comunlinklog /var/log/samba "log.nmbd"

}

#启动日志
startlog() {
  echo "启动日志"
  #/var/log/boot.log
  comunlinklog /var/log "boot"

  #/var/log/dmesg
  comunlinklog /var/log "dmesg"
}

#登录日志
loginlog() {
  echo "登录日志"
  #wtmp日志	last命令获取--last -w --time-format full -i
  comunlinklog /var/log "wtmp"
  #cat /dev/null > /var/log/wtmp

  #btmp日志	lastb命令获取--lastb -w --time-format full -i、使用journalctl命令获取失败原因--journalctl -o short-full /usr/sbin/sshd /usr/bin/login /usr/sbin/lightdm
  comunlinklog /var/log "btmp"
  #cat /dev/null > /var/log/btmp

  #xrdp日志	/var/log/xrdp.log   journalctl -o short-full /usr/sbin/xrdp-sesman
  comunlinklog /var/log "xrdp"

  comunlinklog /var/log "auth"
}

#应用日志
applog() {
  echo "应用日志"
  #dpkg日志	/var/log/dpkg.log
  comunlinklog /var/log "dpkg"

  #alternatives日志	/var/log/alternatives.log
  comunlinklog /var/log "alternatives"

  #access日志	/var/log/cups/access_log
  comunlinklog /var/log/cups "access_log"

  #error日志	/var/log/cups/error_log
  comunlinklog /var/log/cups "error_log"
}

#安全日志
securitylog() {
  echo "安全日志"
  #麒麟安全	/var/log/kysec.log
  comunlinklog /var/log "kysec"

  #崩溃日志	/tmp/core文件、使用journalctl命令获取--journalctl -o short-full SYSLOG_FACILITY=0 | grep segfault

  #审计日志	/var/log/audit/audit.log
  comunlinklog /var/log/audit "audit"

  #天狗 /var/log/ksc-defender/tg.log
  comunlinklog /var/log/ksc-defender "tg"

  #可信 /var/log/trust.log
  comunlinklog /var/log "trust"
}

cleanlogdate() {
  > $CLEANDATEPATH
  date +%Y >> $CLEANDATEPATH
  date +%m >> $CLEANDATEPATH
  date +%d >> $CLEANDATEPATH
  date +%W >> $CLEANDATEPATH
}

cleanlog() {
  echo "开始清除日志"
  
  cleanlogdate

  systemlog
  startlog
  loginlog
  applog
  securitylog

}


check() {
  #检测是否需要执行，如果需要则直接执行
  echo "in check"
  read cleanstatus < $CLEANSTATUSPATH
  echo $cleanstatus
  #echo ${#cleanstatus}
  
  #year=2018
  year=$(sed -n 1P $CLEANDATEPATH)
  month=$(sed -n 2P $CLEANDATEPATH)
  day=$(sed -n 3P $CLEANDATEPATH)
  week=$(sed -n 4P $CLEANDATEPATH)

  case $cleanstatus in
    close)
      echo "check：close状态，直接返回。"
      return
      ;;

    day)
      currentYear=$(date +%Y)
      currentMonth=$(date +%m)
      currentDay=$(date +%d)
      #month="eee"
      if [[ $month = $currentMonth ]]&&[[ $year = $currentYear ]]&&[[ $day = $currentDay ]];then
        echo "check:同一天，退出！"
        return
      else
        cleanlog
      fi
      ;;

    week)
      currentWeek=$(date +%W)
      currentYear=$(date +%Y)
      if [[ $week = $currentWeek ]]&&[[ $year = $currentYear ]];then
        echo "check:同一周，退出！"
        return
      else
        cleanlog
      fi
      ;;

    month)
      currentYear=$(date +%Y)
      currentMonth=$(date +%m)
      #month="eee"
      if [[ $month = $currentMonth ]]&&[[ $year = $currentYear ]];then
        echo "check:同一个月，退出！"
        return
      else
        cleanlog
      fi
      ;;

    *)
      echo "cleanstatus 内容错误"
      ;;
  esac

}

case $1 in
  init)
    echo "初始化"
    init
    ;;
  check)
    echo "检测是否需要执行"
    check
    ;;
  day|close|week|month)
    echo "设置状态为：$1"
    echo $1 > $CLEANSTATUSPATH
    ;;
  clean)
    echo "立即清理日志"
    cleanlog
    ;;
  *)
    echo "无效参数"
    exit
    ;;
esac

echo "=========================="